@@ -634,7 +634,7 @@ void PopUpMenu::activateEntry( int entry )
 void PopUpMenu::setHighlightEntry( int entry, int forward_direction )
 {
     if ( entry >= 0 && entry < (int)m_entries.size() ) {
-        if ( m_highlighted_entry != entry ) {
+        if ( m_highlighted_entry != entry || ! isVisibleEntry( m_highlighted_entry ) ) {
             m_open_after_timeout = true;
             m_highlighted_entry = entry;
 
@@ -942,6 +942,7 @@ bool PopUpMenu::checkForVisibleEntries( const std::string &filter )
         switch ( it1->type ) {
           case NORMAL:
           case SUBMENU:
+          case EDITABLE:
             lower_name = AGUIXUtils::tolower( it1->name );
             if ( lower_name.find( lower_filter ) != std::string::npos ) {
                 return true;
