@@ -521,7 +521,7 @@ CondParser::erg_t *CondParser::factor()
           if ( tstr != NULL ) {
             if ( fe->findOutputAndRV( tstr, &cstr, &retval ) != 0 ) {
               e = (erg_t*)_allocsafe( sizeof( erg_t ) );
-              ec = new ExeClass( ExeClass::EXECUTE_NORMAL );
+              ec = new ExeClass();
               if ( fe != NULL ) {
                 tstr2 = NWC::Path::parentDir( fe->fullname, NULL );
                 if ( tstr2 != NULL ) {
@@ -1193,7 +1193,7 @@ char *CondParser::getOutput( const char *str, FileEntry *tfe )
   tstr = replaceFlags( str );
   
   if ( tstr != NULL ) {
-    ec = new ExeClass( ExeClass::EXECUTE_NORMAL );
+    ec = new ExeClass();
     tstr2 = NWC::Path::parentDir( fe->fullname, NULL );
     if ( tstr2 != NULL ) {
       ec->cdDir( tstr2 );
