@@ -448,6 +448,9 @@ struct mytoken tokenlist[]={
   { SHOWBYFILTER_WCP, "showbyfilter" },
   { SHOWBYPROGRAM_WCP, "showbyprogram" },
   { EXTENSION_WCP, "extension" },
+  { TERMINAL_RETURNS_EARLY_WCP, "terminalreturnsearly" },
+  { DIRECTORYPRESETS_WCP, "directorypresets" },
+  { DIRECTORYPRESET_WCP, "directorypreset" }
 };
 
 ArrayList *tokenlist_sorted = NULL;
