@@ -1,6 +1,6 @@
 /* nmfilter.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2006,2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -165,3 +165,16 @@ NM_Filter *NM_Filter::duplicate()
     fi->setPattern( pattern );
     return fi;
 }
+
+bool NM_Filter::operator==( const NM_Filter &other )
+{
+    if ( _check != other._check ) return false;
+
+    if ( pattern == NULL && other.pattern == NULL ) return true;
+
+    if ( pattern != other.pattern ) return false;
+
+    if ( strcmp( pattern, other.pattern ) == 0 ) return true;
+
+    return false;
+}
