@@ -302,6 +302,7 @@ StartProgOp::startprog( WPUContext *wpu, ActionMessage *am )
         }
 
         std::string exestr;
+        bool remove_after_exec = true;
 
         if ( ( m1->_start == STARTPROGOP_START_IN_TERMINAL_AND_WAIT4KEY )||
              ( m1->_start == STARTPROGOP_START_IN_TERMINAL ) ) {
@@ -310,8 +311,8 @@ StartProgOp::startprog( WPUContext *wpu, ActionMessage *am )
             fp.putStringExt( "echo %s\n", catalog.getLocale( 201 ) );
             fp.putString( "read x\n" );
           }
-          exestr = AGUIXUtils::formatStringToString( wconfig->getTerminalStr(),
-                                                     tmpname );
+
+          exestr = Worker::getTerminalCommand( tmpname, tmpoutput, remove_after_exec );
         } else {
             exestr = "/bin/sh ";
             exestr += tmpname;
@@ -329,7 +330,10 @@ StartProgOp::startprog( WPUContext *wpu, ActionMessage *am )
         if ( fp.errors() == 0 ) {
           worker_chmod( tmpname, 0700 );
           removeTMPFiles = false;
-          am->getWorker()->runCommand( exestr.c_str(), tmpname, tmpoutput, m1->_inbackground, pea );
+          am->getWorker()->runCommand( exestr.c_str(),
+                                       remove_after_exec ? tmpname : NULL,
+                                       remove_after_exec ? tmpoutput : NULL,
+                                       m1->_inbackground, pea );
         } else {
           Requester req( Worker::getAGUIX() );
           char *textstr = (char*)_allocsafe( strlen( catalog.getLocale( 647 ) ) + strlen( tmpname ) + 1 );
