@@ -1,6 +1,6 @@
 /* startprogop.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -25,6 +25,7 @@
 #include "wdefines.h"
 #include "functionproto.h"
 #include <memory>
+#include "ajson.hh"
 
 class FlatTypeList;
 class AWindow;
@@ -149,18 +150,29 @@ protected:
   std::unique_ptr< StartSettings > showGUI();
 
     void updateCompletionList( const std::string &base,
-                               PersistentStringList &history );
+                               PersistentStringList &history,
+                               std::shared_ptr< AJSON::JSONType > &filetype_history );
     void updateSGFromComplete( StringGadget *sg,
                                PersistentStringList &history,
+                               std::shared_ptr< AJSON::JSONType > &filetype_history,
                                FieldListView *lv );
     void updateSGFromRow( int row,
-                          PersistentStringList &history );
+                          PersistentStringList &history,
+                          std::shared_ptr< AJSON::JSONType > &filetype_history );
+    void updateFiletypeHistory( std::shared_ptr< AJSON::JSONType > &filetype_history,
+                                const std::string &base );
 
   std::string default_file;
+  std::string m_default_file_filetype;
   
   std::string gui_msg;
 
-    std::list< std::string > m_current_completions;
+    enum completion_type {
+                          FILETYPE_COMPLETION,
+                          ANY_COMPLETION
+    };
+    
+    std::list< std::pair< completion_type, std::string > > m_current_completions;
     std::string m_current_original_file;
     bool m_completion_enabled;
     std::string m_previous_sg_content;
