@@ -30,6 +30,7 @@
 #include "layoutsettings.hh"
 #include <aguix/aguix.h>
 #include "stringcomparator.hh"
+#include "wconfig_types.hh"
 
 class Worker;
 class WCPath;
@@ -74,34 +75,6 @@ public:
   unsigned int getHBarHeight(int);
   unsigned int getVBarWidth(int);
   const std::vector<WorkerTypes::listcol_t> *getVisCols( int side ) const;
-  void setStatusbar(int,int);
-  void setSelLVB(int,int);
-  void setUnselLVB(int,int);
-  void setSelDir(int,int);
-  void setUnselDir(int,int);
-  void setSelFile(int,int);
-  void setUnselFile(int,int);
-  void setSelDirAct(int,int);
-  void setUnselDirAct(int,int);
-  void setSelFileAct(int,int);
-  void setUnselFileAct(int,int);
-  void setClockbar(int,int);
-  void setRequest(int,int);
-  void setLVHeader( int, int );
-  int getStatusbar(int) const;
-  int getSelLVB(int) const;
-  int getUnselLVB(int) const;
-  int getSelDir(int) const;
-  int getUnselDir(int) const;
-  int getSelFile(int) const;
-  int getUnselFile(int) const;
-  int getSelDirAct(int) const;
-  int getUnselDirAct(int) const;
-  int getSelFileAct(int) const;
-  int getUnselFileAct(int) const;
-  int getClockbar(int) const;
-  int getRequest(int) const;
-  int getLVHeader( int ) const;
   void setStartDir(int,const char*);
   char *getStartDir(int);
   void setFont(int,const char*);
@@ -141,7 +114,7 @@ public:
 
   void applyColorList(List *);
 
-  bool configure();
+  bool configure( const std::string &panel = "" );
 
   int palette();
   int palette(int);
@@ -157,8 +130,6 @@ public:
   void applyLanguage();
   
   const char *getTerminalStr();
-  void setListerBG(int);
-  int getListerBG();
   int getStringForDirSizeLen();
 
   void setDateFormat( int nv );
@@ -369,6 +340,12 @@ public:
 
     void setStoreTabsMode( store_tabs_mode_t );
     store_tabs_mode_t getStoreTabsMode() const;
+
+    void setTerminalReturnsEarly( bool nv );
+    bool getTerminalReturnsEarly() const;
+
+    void setDirectoryPresets( const std::map< std::string, struct directory_presets > &presets );
+    const std::map< std::string, struct directory_presets > &getDirectoryPresets() const;
 protected:
   char *lang;
   unsigned int rows,columns;
@@ -379,20 +356,6 @@ protected:
   unsigned int hbar_height[2];
   unsigned int vbar_width[2];
   std::vector<WorkerTypes::listcol_t> viscols[2];
-  int statusbar[2];
-  int sel_lvb[2];
-  int unsel_lvb[2];
-  int sel_dir[2];
-  int unsel_dir[2];
-  int sel_file[2];
-  int unsel_file[2];
-  int sel_dir_act[2];
-  int unsel_dir_act[2];
-  int sel_file_act[2];
-  int unsel_file_act[2];
-  int clockbar[2];
-  int request[2];
-  int lvheader[2];
   char *dir[2];  // left=0, right=1
   List *paths;  // Elemente sind WCPath
   List *filetypes; // Elemente sind WCFiletype
@@ -469,8 +432,6 @@ protected:
   void initFixTypes();
   void setDefaultConfig();
 
-  int listerbg;
-  
   int export2file( bool export_buttons,
                    bool export_hotkeys,
                    bool export_types,
@@ -535,6 +496,10 @@ protected:
 
     restore_tabs_mode_t m_restore_tabs_mode;
     store_tabs_mode_t m_store_tabs_mode;
+
+    bool m_terminal_returns_early;
+
+    std::map< std::string, struct directory_presets > m_directory_presets;
 };
 
 extern WConfig *wconfig;
