@@ -40,6 +40,7 @@
 #include "kvpstore.hh"
 #include <future>
 #include "worker_types.h"
+#include "pathjumpui_types.hh"
 
 class ListerMode;
 class Lister;
@@ -254,10 +255,16 @@ public:
 
     static KVPStore &getKVPStore();
 
-    void enqueueFuture( std::future< bool > f );
+    void enqueueFuture( std::future< PathJumpUITypes::existence_state_t > f );
 
     std::list< WorkerTypes::reg_command_info_t > getListOfCommandsWithoutArgs() const;
     WorkerTypes::reg_command_info_t getCommandInfo( const std::string &command ) const;
+
+    static std::string getTerminalCommand( const std::string &cmdfile,
+                                           const std::string &outfile,
+                                           bool &remove_after_exec );
+
+    void issueConfigOpen( const std::string &panel );
 protected:
   void createMainWin();
   void setupMainWin();
@@ -265,7 +272,7 @@ protected:
   void shufflePath();
   void shuffleButton( int dir, bool nocycle );
   void about();
-  bool configure();
+  bool configure( const std::string &panel = "" );
   void showPathBank();
   void showButtonBank();
   void setPath(int);
@@ -480,7 +487,9 @@ protected:
 
     TimedText m_button_help_text;
 
-    std::list< std::future< bool > > m_bool_futures;
+    std::list< std::future< PathJumpUITypes::existence_state_t > > m_existence_futures;
+
+    std::string m_pending_config_open;
 };
 
 #endif
