@@ -27,7 +27,7 @@
 #include "nwc_path.hh"
 #include "datei.h"
 
-#define CATENTRY 1328
+#define CATENTRY 1341
 #define CATFLAGENTRY 59
 
 WorkerLocale catalog;
@@ -1429,6 +1429,19 @@ The default value here is the active entry and it's already correctly protected!
   catalog[1325]=dupstring( "Program" );
   catalog[1326]=dupstring( "Last accesses by external program - F3" );
   catalog[1327]=dupstring( "Show accesses by external program" );
+  catalog[1328]=dupstring( "Terminal returns early" );
+  catalog[1329]=dupstring( "Apply color theme presets for a light or dark theme:|Your current palette and UI color settings will be overwritten!|You need to restart Worker to make theme changes active!" );
+  catalog[1330]=dupstring( "Apply light theme" );
+  catalog[1331]=dupstring( "Apply dark theme" );
+  catalog[1332]=dupstring( "Directory presets" );
+  catalog[1333]=dupstring( "Save current settings for current dir" );
+  catalog[1334]=dupstring( "Edit saved settings" );
+  catalog[1335]=dupstring( "Paths with sort and filter presets" );
+  catalog[1336]=dupstring( "Sort settings:" );
+  catalog[1337]=dupstring( "Filter settings:" );
+  catalog[1338]=dupstring( "Sort mode:" );
+  catalog[1339]=dupstring( "Remove filter" );
+  catalog[1340]=dupstring( "Enter directory for which separate sort and|filter settings should be applied to." );
 
 //  catalog[]=dupstring( "" );
   
