@@ -928,7 +928,7 @@ struct WPUContext::ifp_erg *WPUContext::ifp_factor()
   
           if ( tstr != NULL ) {
             e = (struct ifp_erg*)_allocsafe( sizeof( struct ifp_erg ) );
-            std::unique_ptr<ExeClass> ec( new ExeClass( ExeClass::EXECUTE_NORMAL, worker ) );
+            std::unique_ptr<ExeClass> ec( new ExeClass( worker ) );
             ec->cdDir( getBaseDir() );
             ec->addCommand( "%s", tstr );
             e->numval = ec->getReturnCode( &exeerror );
@@ -995,7 +995,7 @@ struct WPUContext::ifp_erg *WPUContext::ifp_factor()
   
           if ( tstr != NULL ) {
             e = (struct ifp_erg*)_allocsafe( sizeof( struct ifp_erg ) );
-            std::unique_ptr<ExeClass> ec( new ExeClass( ExeClass::EXECUTE_NORMAL, worker ) );
+            std::unique_ptr<ExeClass> ec( new ExeClass( worker ) );
             ec->cdDir( getBaseDir() );
             ec->addCommand( "%s", tstr );
             e->strval = ec->getOutput( &exeerror );
